import { Component, OnInit } from '@angular/core';
import { Router } from '@angular/router';
import { IonHeader, IonButton, IonList, IonItem, IonContent, IonIcon, IonLabel, IonTitle, IonToolbar, IonInput, IonSegment, IonSegmentButton, IonSelect, IonSelectOption } from '@ionic/angular/standalone';
import { CommonModule } from '@angular/common';
import { FormsModule } from '@angular/forms'; // 导入 FormsModule
import { HttpClient } from '@angular/common/http';
import { CloudObject } from 'src/lib/ncloud';
import { UserService } from '../user.service'; // 引入 UserService

@Component({
  selector: 'app-page-publishsurvey',
  templateUrl: './page-publishsurvey.component.html',
  styleUrls: ['./page-publishsurvey.component.scss'],
  standalone: true,
  imports: [
    IonHeader, IonToolbar, IonTitle, IonContent, IonSegment, IonSegmentButton, IonSelect, IonSelectOption,
    FormsModule, IonList, IonItem,
    IonLabel, IonIcon, IonButton,
    IonInput,
    CommonModule,
  ]
})

export class PagePublishsurveyComponent implements OnInit {
  category: string = 'school'; // 默认类别
  surveyTitle: string = '';
  surveyLink: string = '';
  targetAudience: string = 'all'; // 默认面向对象
  societySurveyTitle: string = '';
  societySurveyLink: string = '';

  constructor(
    private router: Router,
    private http: HttpClient,
    private userService: UserService // 注入 UserService
  ) {}

  onCategoryChange() {
    console.log(`当前选择的类别: ${this.category}`);
  }

  publishSurvey() {
    const currentUser = this.userService.getCurrentUser();
    if (!currentUser || !currentUser.data || currentUser.data['role'] !== 'teacher') {
      console.log('权限不够');
      alert('权限不够'); // 这里可以替换为更友好的提示方式
      return;
    }

    console.log('发布学校问卷:');
    console.log(`标题: ${this.surveyTitle}`);
    console.log(`链接: ${this.surveyLink}`);
    console.log(`面向对象: ${this.targetAudience}`);

    const surveyData = {
      title: this.surveyTitle,
      link: this.surveyLink,
      audience: this.targetAudience,
    };

    let survey = new CloudObject("Survey");
    survey.set(surveyData);
    survey.save().then(data => {
      console.log('问卷已成功发布', data);
    }).catch(err => {
      console.error('发布问卷时出错', err);
    });
  }

  publishSocietySurvey() {
    const currentUser = this.userService.getCurrentUser();
    if (!currentUser || !currentUser.data || currentUser.data['role'] !== 'teacher') {
      console.log('权限不够');
      alert('权限不够'); // 这里可以替换为更友好的提示方式
      return;
    }

    console.log('发布社会问卷:');
    console.log(`标题: ${this.societySurveyTitle}`);
    console.log(`链接: ${this.societySurveyLink}`);
    // 这里可以添加逻辑将问卷发布到后端或其他处理
  }

  goTab1() {
    this.router.navigate(['tabs/page-psysurvey']);
  }

  ngOnInit() {}
}